@@ -255,11 +255,11 @@ class PhContextFacade(object):
         secret_key = os.getenv("AWS_SECRET_ACCESS_KEY")
         cmd_arr = ["spark-submit",
                    "--master", "yarn",
-                   "--deploy-mode", "cluster",
-                   "--conf", "spark.driver.memory=2g",
-                   "--conf", "spark.driver.cores=2",
+                   "--deploy-mode", "client",
+                   "--conf", "spark.driver.memory=1g",
+                   "--conf", "spark.driver.cores=1",
                    "--conf", "spark.executor.memory=2g",
-                   "--conf", "spark.executor.cores=2",
+                   "--conf", "spark.executor.cores=1",
                    "--conf", "spark.driver.extraJavaOptions=-Dcom.amazonaws.services.s3.enableV4",
                    "--conf", "spark.executor.extraJavaOptions=-Dcom.amazonaws.services.s3.enableV4",
                    "--conf", "spark.hadoop.fs.s3a.impl=org.apache.hadoop.fs.s3a.S3AFileSystem",
